==> ghemical_0.82.orig.tar.gz: ghemical-0.82.orig/src/common/qm2mdl.h <==
// QM2MDL.H : model class for atomic QM models (to view basis sets?!?!?!)...

// Copyright (C) 2000 Tommi Hassinen.

// This program is free software; you can redistribute it and/or modify it
// under the terms of the license (GNU GPL) which comes with this package.

/*################################################################################################*/

#include "config.h"	// this is target-dependent...

#ifndef QM2MDL_H
#define QM2MDL_H

class qm2_mdl;

/*################################################################################################*/

#include "model.h"

#include "utility.h"

/*################################################################################################*/

/**	A "##model" class for atomic quantum mechanics models. 
	Under construction: could be perhaps used to view/develop bases sets etc. 
	Nothing useful here so far...
*/

class qm2_mdl : virtual public model_simple
{
	protected:
	
	element el;
	
	public:
	
	qm2_mdl(ostream *, class_factory &);
	~qm2_mdl(void);
	
	const char * GetProjectFileNameExtension(void);		// virtual
	
	bool ReadStream(istream &, bool = false) { return false; }	// virtual
	void WriteStream(ostream &) { }					// virtual
	
	/** someday we might move ImportFile() to all_atoms_interface,
	    but at the moment we just have a dummy function here...
	*/
	bool ImportFile(const char*, int) { return false; }	// virtual
};

/*################################################################################################*/

#endif	// QM2MDL_H

// eof

==> ghemical_1.01.orig.tar.gz: ghemical-1.01/src/common/qm2mdl.h <==
// QM2MDL.H : model class for atomic QM models (to view basis sets?!?!?!)...

// Copyright (C) 2000 Tommi Hassinen.

// This program is free software; you can redistribute it and/or modify it
// under the terms of the license (GNU GPL) which comes with this package.

/*################################################################################################*/

#include "config.h"	// this is target-dependent...

#ifndef QM2MDL_H
#define QM2MDL_H

class qm2_mdl;

/*################################################################################################*/

#include "model.h"

#include "utility.h"

/*################################################################################################*/

/**	A "##model" class for atomic quantum mechanics models. 
	Under construction: could be perhaps used to view/develop bases sets etc. 
	Nothing useful here so far...
*/

class qm2_mdl : virtual public model_simple
{
	protected:
	
	element el;
	
	public:
	
	qm2_mdl(ostream *, class_factory &);
	~qm2_mdl(void);
	
	const char * GetProjectFileNameExtension(void);		// virtual

	bool ReadStream(istream &, bool, bool = false) { return false; }	// virtual
	void WriteStream(ostream &) { }						// virtual
	
	/** someday we might move ImportFile() to all_atoms_interface,
	    but at the moment we just have a dummy function here...
	*/
	bool ImportFile(const char*, int) { return false; }	// virtual
};

/*################################################################################################*/

#endif	// QM2MDL_H

// eof
